@@ -7,18 +7,20 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
+#include <config-libkleo.h>
+
 #include "filenamerequester.h"
 
 #include <KLocalizedString>
 
-#include <QHBoxLayout>
-#include <QToolButton>
 #include <QCompleter>
-#include <QDirModel>
-#include <QString>
-#include <QFileDialog>
 #include <QEvent>
+#include <QFileDialog>
+#include <QFileSystemModel>
+#include <QHBoxLayout>
 #include <QLineEdit>
+#include <QString>
+#include <QToolButton>
 
 using namespace Kleo;
 
@@ -26,6 +28,7 @@ class Q_DECL_HIDDEN FileNameRequester::FileNameRequesterPrivate
 {
     friend class ::Kleo::FileNameRequester;
     FileNameRequester *const q;
+
 public:
     explicit FileNameRequesterPrivate(FileNameRequester *qq);
     ~FileNameRequesterPrivate();
@@ -35,7 +38,7 @@ private:
 
 private:
 #ifndef QT_NO_DIRMODEL
-    QDirModel  dirmodel;
+    QFileSystemModel dirmodel;
     QCompleter completer;
 #else
     QDir::Filters filter;
@@ -50,26 +53,29 @@ private:
 };
 
 FileNameRequester::FileNameRequesterPrivate::FileNameRequesterPrivate(FileNameRequester *qq)
-    : q(qq),
+    : q(qq)
+    ,
 #ifndef QT_NO_DIRMODEL
-      dirmodel(),
-      completer(&dirmodel),
+    dirmodel()
+    , completer(&dirmodel)
+    ,
 #else
-      filter(),
+    filter()
+    ,
 #endif
-      lineedit(q),
-      button(q),
-      hlay(q),
-      nameFilter(),
-      existingOnly(true)
+    lineedit(q)
+    , button(q)
+    , hlay(q)
+    , nameFilter()
+    , existingOnly(true)
 {
 #ifndef QT_NO_DIRMODEL
-    dirmodel.setObjectName(QStringLiteral("dirmodel"));
-    completer.setObjectName(QStringLiteral("completer"));
+    dirmodel.setObjectName(QLatin1StringView("dirmodel"));
+    completer.setObjectName(QLatin1StringView("completer"));
 #endif
-    lineedit.setObjectName(QStringLiteral("lineedit"));
-    button.setObjectName(QStringLiteral("button"));
-    hlay.setObjectName(QStringLiteral("hlay"));
+    lineedit.setObjectName(QLatin1StringView("lineedit"));
+    button.setObjectName(QLatin1StringView("button"));
+    hlay.setObjectName(QLatin1StringView("hlay"));
 
     button.setIcon(QIcon::fromTheme(QStringLiteral("document-open")));
     button.setToolTip(i18n("Open file dialog"));
@@ -84,20 +90,25 @@ FileNameRequester::FileNameRequesterPrivate::FileNameRequesterPrivate(FileNameRe
     q->setFocusPolicy(lineedit.focusPolicy());
     q->setFocusProxy(&lineedit);
 
-    connect(&button, &QToolButton::clicked, q, [this]() { slotButtonClicked(); });
+    connect(&button, &QToolButton::clicked, q, [this]() {
+        slotButtonClicked();
+    });
     connect(&lineedit, &QLineEdit::textChanged, q, &FileNameRequester::fileNameChanged);
 }
 
-FileNameRequester::FileNameRequesterPrivate::~FileNameRequesterPrivate() {}
+FileNameRequester::FileNameRequesterPrivate::~FileNameRequesterPrivate()
+{
+}
 
 FileNameRequester::FileNameRequester(QWidget *p)
-    : QWidget(p), d(new FileNameRequesterPrivate(this))
+    : QWidget(p)
+    , d(new FileNameRequesterPrivate(this))
 {
-
 }
 
 FileNameRequester::FileNameRequester(QDir::Filters f, QWidget *p)
-    : QWidget(p), d(new FileNameRequesterPrivate(this))
+    : QWidget(p)
+    , d(new FileNameRequesterPrivate(this))
 {
 #ifndef QT_NO_DIRMODEL
     d->dirmodel.setFilter(f);
