@@ -86,10 +86,14 @@ static const QSet<QString> mimeFileNames{
     /* KMail standard name */
     QStringLiteral("msg.asc"),
     QStringLiteral("smime.p7m"),
-    /* Old names of GpgOL attachments newer versions
-     * should use .mim file ending. */
     QStringLiteral("openpgp-encrypted-message.asc"),
+    /* Old names of internal GpgOL attachments newer versions
+     * should use .mime file ending as it is connected with
+     * Kleopatra. */
     QStringLiteral("GpgOL_MIME_structure.txt"),
+    QStringLiteral("GpgOL_MIME_structure.mime"),
+    /* This is gpgtools take on the filename */
+    QStringLiteral("OpenPGP encrypted message.asc"),
 };
 
 static const unsigned int defaultClassification = NoClass;
@@ -246,7 +250,7 @@ QString Kleo::printableClassification(unsigned int classification)
     if (classification & Kleo::Class::MimeFile) {
         parts.push_back(QStringLiteral("MimeFile"));
     }
-    return parts.join(QLatin1String(", "));
+    return parts.join(QLatin1StringView(", "));
 }
 
 /*!
@@ -302,7 +306,7 @@ QString Kleo::outputFileName(const QString &inputFileName)
     const QString suffix = fi.suffix();
 
     if (classifications.find(suffix) == std::cend(classifications)) {
-        return inputFileName + QLatin1String(".out");
+        return inputFileName + QLatin1StringView(".out");
     } else {
 #ifdef Q_OS_WIN
         return stripOutlookAttachmentNumbering(inputFileName.chopped(suffix.size() + 1));
